==> openGion_dev_5.9.13.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE17S.sql <==
/****************************************************************************/
/* GE17 ( URL転送ﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2016/10/07 10:39:44                                            */
/****************************************************************************/
CREATE TABLE GE17 (
   SYSTEM_ID    varchar           (   10 )                          NOT NULL            /*  10 ｼｽﾃﾑID   */
 , RANDOM_KEY   varchar           (   32 )                          NOT NULL            /*  20 ﾗﾝﾀﾞﾑｷｰ  */
 , NAME_JA      varchar           (  200 )                                              /*  30 名称     */
 , DYVALID      varchar           (    8 )      DEFAULT 99999999    NOT NULL            /*  40 有効日   */
 , REDIRECT_URL varchar           ( 4000 )                          NOT NULL            /*  50 転送URL  */
 , UNIQ         int IDENTITY(1,1)                                                       /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT 1           NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                              /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                              /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                              /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                              /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                              /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                              /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                              /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                              /* 890 更新者   */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GE17S.sql <==
/****************************************************************************/
/* GE17 ( URL転送ﾃｰﾌﾞﾙ )                                                    */
/*                                                                          */
/* Created : 2017/04/07 09:50:28                                            */
/****************************************************************************/
CREATE TABLE GE17 (
   SYSTEM_ID    varchar           (   10 )                          NOT NULL            /*  10 ｼｽﾃﾑID   */
 , RANDOM_KEY   varchar           (   32 )                          NOT NULL            /*  20 ﾗﾝﾀﾞﾑｷｰ  */
 , NAME_JA      varchar           (  200 )                                              /*  30 名称     */
 , DYVALID      varchar           (    8 )      DEFAULT '99999999'  NOT NULL            /*  40 有効日   */
 , REDIRECT_URL varchar           ( 4000 )                          NOT NULL            /*  50 転送URL  */
 , UNIQ         int IDENTITY(1,1)                                                       /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (    1 )      DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (   14 )                                              /* 820 登録日時 */
 , PGSET        varchar           (   10 )                                              /* 830 作成PG   */
 , PGPSET       varchar           (   10 )                                              /* 840 作成親PG */
 , USRSET       varchar           (   10 )                                              /* 850 作成社員 */
 , DYUPD        varchar           (   14 )                                              /* 860 更新日時 */
 , PGUPD        varchar           (   10 )                                              /* 870 更新PG   */
 , PGPUPD       varchar           (   10 )                                              /* 880 更新親PG */
 , USRUPD       varchar           (   10 )                                              /* 890 更新者   */
);
